Author: Sergey Aganezov

# CAMSA report

### Assemblies overview

ID | Name | # APs | Orientations (O / SO / U) | NC | OC / OSC | IC / ISC | MAP
--- | --- | --- | --- | --- | --- | --- | ---
A1 | scaffmatch | 53 | 53 / 0 / 0 | 48 | 5 / 0 | 0 / 0 | 51 (96.23 %)
A2 | sga | 43 | 43 / 0 / 0 | 40 | 3 / 0 | 0 / 0 | 42 (97.67 %)
A3 | soap2 | 54 | 54 / 0 / 0 | 49 | 5 / 0 | 0 / 0 | 51 (94.44 %)
A4 | sspace | 51 | 51 / 0 / 0 | 48 | 3 / 0 | 0 / 0 | 50 (98.04 %)
ID | Name | # APs | Orientations (O / SO / U) | NC | OC / OSC | IC / ISC | MAP

### Individual assemblies

scaffmatch [A1]

Seq1 | Seq2 | Or1 | Or2 | Or | ISC | IC | OSC | OC | Unique | MAP
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
contig_29 | contig_58 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_56 | contig_57 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_32 | contig_33 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_20 | contig_65 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_16 | contig_17 | + | + | O | 0 | 0 | 0 | 1 | 0 | 1
contig_21 | contig_22 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_1 | contig_50 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_7 | contig_8 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_43 | contig_44 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_32 | contig_34 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_12 | contig_27 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_35 | contig_37 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_13 | contig_26 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_23 | contig_40 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_40 | contig_66 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_29 | contig_30 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_35 | contig_39 | - | - | O | 0 | 0 | 0 | 1 | 0 | 1
contig_38 | contig_60 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_12 | contig_22 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_39 | contig_42 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_48 | contig_63 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_19 | contig_7 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_42 | contig_58 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_37 | contig_38 | + | + | O | 0 | 0 | 0 | 1 | 0 | 1
contig_18 | contig_19 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_3 | contig_34 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_20 | contig_27 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_17 | contig_55 | + | + | O | 0 | 0 | 0 | 1 | 1 | 0
contig_18 | contig_4 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_53 | contig_8 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_33 | contig_59 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_25 | contig_26 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_0 | contig_5 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_55 | contig_64 | + | + | O | 0 | 0 | 0 | 1 | 1 | 0
contig_15 | contig_66 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_23 | contig_4 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_46 | contig_47 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_14 | contig_62 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_15 | contig_49 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_43 | contig_46 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_36 | contig_60 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_2 | contig_21 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_54 | contig_59 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_30 | contig_53 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_2 | contig_5 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_25 | contig_65 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_13 | contig_3 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_36 | contig_61 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_16 | contig_51 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_41 | contig_61 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_0 | contig_48 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_1 | contig_56 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_54 | contig_64 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
Seq1 | Seq2 | Or1 | Or2 | Or | ISC | IC | OSC | OC | Unique | MAP

sga [A2]

Seq1 | Seq2 | Or1 | Or2 | Or | ISC | IC | OSC | OC | Unique | MAP
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
contig_56 | contig_57 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_32 | contig_33 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_20 | contig_65 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_16 | contig_17 | + | + | O | 0 | 0 | 0 | 1 | 0 | 1
contig_21 | contig_22 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_1 | contig_50 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_7 | contig_8 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_32 | contig_34 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_12 | contig_27 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_13 | contig_26 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_23 | contig_40 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_40 | contig_66 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_17 | contig_64 | + | + | O | 0 | 0 | 0 | 1 | 0 | 1
contig_12 | contig_22 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_48 | contig_63 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_19 | contig_7 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_42 | contig_58 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_18 | contig_19 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_3 | contig_34 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_20 | contig_27 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_18 | contig_4 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_53 | contig_8 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_33 | contig_59 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_25 | contig_26 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_0 | contig_5 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_15 | contig_66 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_38 | contig_39 | - | - | O | 0 | 0 | 0 | 1 | 0 | 0
contig_23 | contig_4 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_14 | contig_62 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_15 | contig_49 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_36 | contig_60 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_2 | contig_21 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_54 | contig_59 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_30 | contig_53 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_2 | contig_5 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_25 | contig_65 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_13 | contig_3 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_36 | contig_61 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_16 | contig_51 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_41 | contig_61 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_0 | contig_48 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_1 | contig_56 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_54 | contig_64 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
Seq1 | Seq2 | Or1 | Or2 | Or | ISC | IC | OSC | OC | Unique | MAP

soap2 [A3]

Seq1 | Seq2 | Or1 | Or2 | Or | ISC | IC | OSC | OC | Unique | MAP
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
contig_29 | contig_58 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_56 | contig_57 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_32 | contig_33 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_20 | contig_65 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_21 | contig_22 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_17 | contig_55 | - | - | O | 0 | 0 | 0 | 1 | 1 | 0
contig_1 | contig_50 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_7 | contig_8 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_43 | contig_44 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_32 | contig_34 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_12 | contig_27 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_35 | contig_37 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_13 | contig_26 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_23 | contig_40 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_40 | contig_66 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_29 | contig_30 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_17 | contig_64 | + | + | O | 0 | 0 | 0 | 1 | 0 | 1
contig_35 | contig_39 | - | - | O | 0 | 0 | 0 | 1 | 0 | 1
contig_38 | contig_60 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_12 | contig_22 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_39 | contig_42 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_48 | contig_63 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_19 | contig_7 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_42 | contig_58 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_37 | contig_38 | + | + | O | 0 | 0 | 0 | 1 | 0 | 1
contig_18 | contig_19 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_3 | contig_34 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_20 | contig_27 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_18 | contig_4 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_53 | contig_8 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_33 | contig_59 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_44 | contig_45 | - | - | O | 0 | 0 | 0 | 0 | 1 | 0
contig_25 | contig_26 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_0 | contig_5 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_15 | contig_66 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_23 | contig_4 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_46 | contig_47 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_16 | contig_55 | + | + | O | 0 | 0 | 0 | 1 | 1 | 0
contig_14 | contig_62 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_15 | contig_49 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_43 | contig_46 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_36 | contig_60 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_2 | contig_21 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_54 | contig_59 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_30 | contig_53 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_2 | contig_5 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_25 | contig_65 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_13 | contig_3 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_36 | contig_61 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_16 | contig_51 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_41 | contig_61 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_0 | contig_48 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_1 | contig_56 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_54 | contig_64 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
Seq1 | Seq2 | Or1 | Or2 | Or | ISC | IC | OSC | OC | Unique | MAP

sspace [A4]

Seq1 | Seq2 | Or1 | Or2 | Or | ISC | IC | OSC | OC | Unique | MAP
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
contig_29 | contig_58 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_56 | contig_57 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_32 | contig_33 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_20 | contig_65 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_16 | contig_17 | + | + | O | 0 | 0 | 0 | 1 | 0 | 1
contig_21 | contig_22 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_1 | contig_50 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_7 | contig_8 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_43 | contig_44 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_32 | contig_34 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_12 | contig_27 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_13 | contig_26 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_23 | contig_40 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_40 | contig_66 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_29 | contig_30 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_17 | contig_64 | + | + | O | 0 | 0 | 0 | 1 | 0 | 1
contig_38 | contig_60 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_12 | contig_22 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_39 | contig_42 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_48 | contig_63 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_19 | contig_7 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_42 | contig_58 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_18 | contig_19 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_3 | contig_34 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_20 | contig_27 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_18 | contig_4 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_53 | contig_8 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_33 | contig_59 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_25 | contig_26 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_0 | contig_5 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_15 | contig_66 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_38 | contig_39 | - | - | O | 0 | 0 | 0 | 1 | 0 | 0
contig_45 | contig_47 | - | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_23 | contig_4 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_46 | contig_47 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_14 | contig_62 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_15 | contig_49 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_43 | contig_46 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_36 | contig_60 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_2 | contig_21 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_54 | contig_59 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_30 | contig_53 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_2 | contig_5 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_25 | contig_65 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_13 | contig_3 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_36 | contig_61 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_16 | contig_51 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_41 | contig_61 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
contig_0 | contig_48 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_1 | contig_56 | + | + | O | 0 | 0 | 0 | 0 | 0 | 1
contig_54 | contig_64 | - | - | O | 0 | 0 | 0 | 0 | 0 | 1
Seq1 | Seq2 | Or1 | Or2 | Or | ISC | IC | OSC | OC | Unique | MAP

### Aggregated assembly points

[ scaffmatch (A1); sga (A2); soap2 (A3); sspace (A4) ]

Advanced filter options
Sources:
Seq1:
Seq2:
Or1:
Or2:
Or:
ISC:
IC:
OSC:
OC:
MAP:
APid:
Expanded only

Fragment length filtration is not available, as no data regarding fragments length was provided

Logical `OR` per search fields

| Sources | Seq1 | Seq2 | OOr1 | OOr2 | POr1 | POr2 | Or1 | Or2 | CW | Or | ISC | IC | OSC | OC | MAP | self_id | detailed
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
| [A1, A3, A4] | contig_29 | contig_58 | + | + | + | + | + | + | 3.0 | O | 0 | 0 | 0 | 0 | 1 | m_0 | 0
| [A1, A2, A3, A4] | contig_56 | contig_57 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_1 | 0
| [A1, A2, A3, A4] | contig_32 | contig_33 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_2 | 0
| [A1, A2, A3, A4] | contig_20 | contig_65 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_3 | 0
| [A1, A2, A4] | contig_16 | contig_17 | + | + | + | + | + | + | 3.0 | O | 0 | 0 | 0 | [A3] | 1 | m_4 | 0
| [A1, A2, A3, A4] | contig_21 | contig_22 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_5 | 0
| [A3] | contig_17 | contig_55 | - | - | None | None | - | - | 1.0 | O | 0 | 0 | 0 | [A1, A2, A4] | 0 | m_6 | 0
| [A1, A2, A3, A4] | contig_1 | contig_50 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_7 | 0
| [A1, A2, A3, A4] | contig_7 | contig_8 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_8 | 0
| [A1, A3, A4] | contig_43 | contig_44 | - | - | - | - | - | - | 3.0 | O | 0 | 0 | 0 | 0 | 1 | m_9 | 0
| [A1, A2, A3, A4] | contig_32 | contig_34 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_10 | 0
| [A1, A2, A3, A4] | contig_12 | contig_27 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_11 | 0
| [A1, A3] | contig_35 | contig_37 | + | + | + | + | + | + | 2.0 | O | 0 | 0 | 0 | 0 | 1 | m_12 | 0
| [A1, A2, A3, A4] | contig_13 | contig_26 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_13 | 0
| [A1, A2, A3, A4] | contig_23 | contig_40 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_14 | 0
| [A1, A2, A3, A4] | contig_40 | contig_66 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_15 | 0
| [A1, A3, A4] | contig_29 | contig_30 | - | - | - | - | - | - | 3.0 | O | 0 | 0 | 0 | 0 | 1 | m_16 | 0
| [A2, A3, A4] | contig_17 | contig_64 | + | + | + | + | + | + | 3.0 | O | 0 | 0 | 0 | [A1] | 1 | m_17 | 0
| [A1, A3] | contig_35 | contig_39 | - | - | - | - | - | - | 2.0 | O | 0 | 0 | 0 | [A2, A4] | 1 | m_18 | 0
| [A1, A3, A4] | contig_38 | contig_60 | + | + | + | + | + | + | 3.0 | O | 0 | 0 | 0 | 0 | 1 | m_19 | 0
| [A1, A2, A3, A4] | contig_12 | contig_22 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_20 | 0
| [A1, A3, A4] | contig_39 | contig_42 | - | - | - | - | - | - | 3.0 | O | 0 | 0 | 0 | 0 | 1 | m_21 | 0
| [A1, A2, A3, A4] | contig_48 | contig_63 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_22 | 0
| [A1, A2, A3, A4] | contig_19 | contig_7 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_23 | 0
| [A1, A2, A3, A4] | contig_42 | contig_58 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_24 | 0
| [A1, A3] | contig_37 | contig_38 | + | + | + | + | + | + | 2.0 | O | 0 | 0 | 0 | [A2, A4] | 1 | m_25 | 0
| [A1, A2, A3, A4] | contig_18 | contig_19 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_26 | 0
| [A1, A2, A3, A4] | contig_3 | contig_34 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_27 | 0
| [A1, A2, A3, A4] | contig_20 | contig_27 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_28 | 0
| [A1] | contig_17 | contig_55 | + | + | None | None | + | + | 1.0 | O | 0 | 0 | 0 | [A2, A3, A4] | 0 | m_29 | 0
| [A1, A2, A3, A4] | contig_18 | contig_4 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_30 | 0
| [A1, A2, A3, A4] | contig_53 | contig_8 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_31 | 0
| [A1, A2, A3, A4] | contig_33 | contig_59 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_32 | 0
| [A3] | contig_44 | contig_45 | - | - | None | None | - | - | 1.0 | O | 0 | 0 | 0 | 0 | 0 | m_33 | 0
| [A1, A2, A3, A4] | contig_25 | contig_26 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_34 | 0
| [A1, A2, A3, A4] | contig_0 | contig_5 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_35 | 0
| [A1] | contig_55 | contig_64 | + | + | None | None | + | + | 1.0 | O | 0 | 0 | 0 | [A2, A3, A4] | 0 | m_36 | 0
| [A1, A2, A3, A4] | contig_15 | contig_66 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_37 | 0
| [A2, A4] | contig_38 | contig_39 | - | - | None | None | - | - | 2.0 | O | 0 | 0 | 0 | [A1, A3] | 0 | m_38 | 0
| [A4] | contig_45 | contig_47 | - | - | - | - | - | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_39 | 0
| [A1, A2, A3, A4] | contig_23 | contig_4 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_40 | 0
| [A1, A3, A4] | contig_46 | contig_47 | + | + | + | + | + | + | 3.0 | O | 0 | 0 | 0 | 0 | 1 | m_41 | 0
| [A3] | contig_16 | contig_55 | + | + | None | None | + | + | 1.0 | O | 0 | 0 | 0 | [A1, A2, A4] | 0 | m_42 | 0
| [A1, A2, A3, A4] | contig_14 | contig_62 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_43 | 0
| [A1, A2, A3, A4] | contig_15 | contig_49 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_44 | 0
| [A1, A3, A4] | contig_43 | contig_46 | + | + | + | + | + | + | 3.0 | O | 0 | 0 | 0 | 0 | 1 | m_45 | 0
| [A1, A2, A3, A4] | contig_36 | contig_60 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_46 | 0
| [A1, A2, A3, A4] | contig_2 | contig_21 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_47 | 0
| [A1, A2, A3, A4] | contig_54 | contig_59 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_48 | 0
| [A1, A2, A3, A4] | contig_30 | contig_53 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_49 | 0
| [A1, A2, A3, A4] | contig_2 | contig_5 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_50 | 0
| [A1, A2, A3, A4] | contig_25 | contig_65 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_51 | 0
| [A1, A2, A3, A4] | contig_13 | contig_3 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_52 | 0
| [A1, A2, A3, A4] | contig_36 | contig_61 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_53 | 0
| [A1, A2, A3, A4] | contig_16 | contig_51 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_54 | 0
| [A1, A2, A3, A4] | contig_41 | contig_61 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_55 | 0
| [A1, A2, A3, A4] | contig_0 | contig_48 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_56 | 0
| [A1, A2, A3, A4] | contig_1 | contig_56 | + | + | + | + | + | + | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_57 | 0
| [A1, A2, A3, A4] | contig_54 | contig_64 | - | - | - | - | - | - | 4.0 | O | 0 | 0 | 0 | 0 | 1 | m_58 | 0
| Sources | Seq1 | Seq2 | OOr1 | OOr2 | POr1 | POr2 | Or1 | Or2 | CW | Or | ISC | IC | OSC | OC | MAP | self_id | detailed

How to interpret and work with the table

#### How to interpret column values

- Sources: column represents the list of assemblies, that reported a particular assembly point. Assemblies are referred to by there ids, which in turn can be found in Assemblies summary table, as well as next to each assembly in the Individual assemblies section
- Seq1: column corresponds to first, out of two fragments, that participate in the reported assembly point.
- Seq2: column corresponds to second, out of two fragments, that participate in the reported assembly point
- Or1: column corresponds to relative orientation of Seq1 wrt Seq2 in the reported assembly.
  1. + orientation corresponds to the head of Seq1 being adjacent in the reported assembly
  2. - orientation corresponds to the tail of Seq1 being adjacent in the reported assembly
- Or2: column corresponds to relative orientation of Seq2 wrt Seq1 in the reported assembly.
  1. + orientation corresponds to the tail of Seq2 being adjacent in the reported assembly
  2. - orientation corresponds to the head of Seq2 being adjacent in the reported assembly
- CW: confidence weight (score) for the reported assembly point. Equals to the sum of assembly points's scores, reported by each source
- Or: a flag determining the class of the assembly point:
  1. O: oriented assembly point, that is for both fragments their extremities are specified
  2. SO: semi-oriented assembly point, that is only for one out of two fragments an assembly extremity is specified
  3. U: unoriented assembly point, that is for both fragments their extremities used for assembly are not specified
- ISC: corresponds to the list of sources, with which this assembly point is In-SemiConflicted. This is the case, when the assembly point (by some, but not all of its realizations) is conflicted with some other assembly point (with some, but not all of later one's realizations), and they both come from same source.
  0 is specified if no in-semiconflicts were identified for this point.
- IC: corresponds to the list of sources, with which this assembly point is In-Conflicted. This is the case, if the assembly point (by all of its realizations), is conflicted with some other assembly point (by all of later one's realizations), and they both come from the same source.
  0 is specified if no in-conflicts were identified for this point.
- OSC: corresponds to the list of sources, with which this assembly point is Out-SemiConflicted. This is the case, when the assembly point (by some, but not all of its representations) is conflicted with some other assembly point (with some, but not all of later one's realizations), and they come from the different sources. 0 is specified is no out-semiconflicts were identified for this point.
- OC: corresponds to the list of sources, with which this assembly point is Out-Conflicted. This is the case, when the assembly point (by all of its representations) is conflicted with some other assembly point (with all of later one's realizations), and they come from the different sources. 0 is specified is no out-semiconflicts were identified for this point.
- MAP: is a flag (i.e. either 0 or 1) corresponding to whether this assembly point participates in the reported Merged-Assembly.

#### How to filter and order information in the table

- Built-in filters: every column has a filter in the table heading.
  1. If the filter is represented an input field, then the smart Datatables search is used.
  2. If the input is represented with a dropdown, then all rows with values matching the chosen value will be kept.
  3. There is a table-wide filter on the top right of the table. Again the smart search is used, but in this case it is table-wide, not column specific.
- Advanced filtering: There is a panel with advance filtering capabilities. Please refer to instructions in it.

Built-in and advanced filters can be combined together. The only difference is that build in filters revert filtering changes on-the-fly, once the filter criteria is removed, while for advanced filtering has to be manually reverted, with the "Remove all filters button".

using
layout

## Filter the table and draw the first graph

How to interpret and work with the graph

## Reading the graph

### Coloring

A1
A2
A3
A4

### Edges

- Scaffold edge: is a directed black edge with scaffold name written on it. Represents the scaffold, participating in one or more assembly points. Direction of the edge corresponds to its relative orientation.
  Example:

- Assembly edge: colored (based on the source assembly) undirected edge corresponding to the reported assembly point.
  - Candidate: all assembly edges from un/semi-oriented assembly points are shown as dashed.
    Example:

  - Exact: all assembly edges from orientedassembly points are shown as solid.
    Example:

  If the edge is shown in bold, it means that the assembly point (its particular realization , corresponding to the egde), participates in the produced merged assembly.
  Example:

  Parallel assembly edges of several colors correspond to assembly points' representations, where the colors determine the list of source assemblies.
  Example:

### Modifying the graph

- Zooming: using the scroll of the mouse, one can zoom in and out of the graph. Note that the position of the pointer determines where the zoom will be focused.
- Moving: use the standard drag operation to move the graph
- Fitting: to fit the whole drawn graph in the frame, use the Fit button at the top of the picture

### Saving graph image

Using the Save button on the top of the graph image itself, one can save the current view of the graph as a png picture.

Coming soon! Please follow GitHub repository of CAMSA to be notified about new releases.
Coming soon! Please follow GitHub repository of CAMSA to be notified about new releases.

Dr. Max A. Alekseyev: maxal@gwu.edu

The project is supported by the National Science Foundation under Grant No. IIS-1462107.

2016 - 2016